==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/SliceEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SliceEventArgsDescription } from "./SliceEventArgsDescription";
/**
 * @hidden
 */
export let SliceEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class SliceEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (SliceEventArgsDescriptionMetadata.a == null) {
                SliceEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                SliceEventArgsDescriptionMetadata.c(SliceEventArgsDescriptionMetadata.a);
            }
            if (a.j(SliceEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.y(SliceEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("IsSelected", "Boolean");
            a.item("IsExploded", "Boolean");
            a.item("OriginalEventRef", "(w:OriginalEvent,wf:OriginalEvent)DataRef");
        }
        static d(a) {
            SliceEventArgsDescriptionMetadata.b(a);
            a.aa("SliceEventArgs", () => new SliceEventArgsDescription());
            a.z("SliceEventArgs", SliceEventArgsDescriptionMetadata.a);
        }
    }
    SliceEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(SliceEventArgsDescriptionMetadata, 'SliceEventArgsDescriptionMetadata');
    SliceEventArgsDescriptionMetadata.a = null;
    return SliceEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/SliceEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SliceEventArgsDescription } from "./SliceEventArgsDescription";
/**
 * @hidden
 */
export let SliceEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class SliceEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (SliceEventArgsDescriptionMetadata.a == null) {
                SliceEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                SliceEventArgsDescriptionMetadata.c(SliceEventArgsDescriptionMetadata.a);
            }
            if (a.k(SliceEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(SliceEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("IsSelected", "Boolean");
            a.item("IsExploded", "Boolean");
            a.item("OriginalEventRef", "(w:OriginalEvent,wf:OriginalEvent)DataRef");
        }
        static d(a) {
            SliceEventArgsDescriptionMetadata.b(a);
            a.ac("SliceEventArgs", () => new SliceEventArgsDescription());
            a.ab("SliceEventArgs", SliceEventArgsDescriptionMetadata.a);
        }
    }
    SliceEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(SliceEventArgsDescriptionMetadata, 'SliceEventArgsDescriptionMetadata');
    SliceEventArgsDescriptionMetadata.a = null;
    return SliceEventArgsDescriptionMetadata;
})();
